use actix_web::{web, HttpResponse, Responder};
use sqlx::PgPool;

use crate::{
    endpoints::IdPath,
    utils::{self, ApplicationError},
};
use brass_db::models::{Assignment, Event, Role, User};

#[actix_web::delete("/events/{id}")]
pub async fn delete(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
    path: web::Path<IdPath>,
) -> Result<impl Responder, ApplicationError> {
    if user.role != Role::Admin && user.role != Role::AreaManager {
        return Err(ApplicationError::Unauthorized);
    }

    let Some(event) = Event::read_by_id_including_location(pool.get_ref(), path.id).await? else {
        return Ok(HttpResponse::NotFound().finish());
    };

    if user.role != Role::Admin && user.area_id != event.location.as_ref().unwrap().area_id {
        return Ok(HttpResponse::BadRequest().body("Can't use location outside of your area"));
    }

    let assignments_for_event = Assignment::read_all_by_event(pool.get_ref(), event.id).await?;

    if !assignments_for_event.is_empty() {
        return Ok(HttpResponse::BadRequest().body("Can't delete event when people are assigned"));
    }

    Event::delete(pool.get_ref(), event.id).await?;

    let url = utils::get_return_url_for_date(&event.start.date());
    Ok(HttpResponse::Ok()
        .insert_header(("HX-LOCATION", url))
        .finish())
}
