use lettre::{
    message::{Mailbox, SinglePart},
    Address, AsyncTransport, Message,
};
use tracing::{debug, instrument};

use crate::utils::ApplicationError;

use super::Mailer;

impl Mailer {
    #[instrument]
    pub async fn send_test_mail(&self, to: &str) -> Result<(), ApplicationError> {
        let sender_mailbox = Mailbox::new(
            Some("noreply".to_string()),
            Address::new("noreply", &self.hostname)?,
        );

        let message = Message::builder()
            .from(sender_mailbox.clone())
            .reply_to(sender_mailbox)
            .to(to.parse()?)
            .subject("Brass: Test E-Mail")
            .singlepart(SinglePart::plain(
                "Testmail von Brass. E-Mail Versand funktioniert!".to_string(),
            ))?;

        debug!("constructed test message");

        self.transport.send(message).await?;
        debug!("sent test message");

        Ok(())
    }
}
